@@ -165,6 +165,9 @@
 /* define if you have getdevs() */
 #undef HAVE_GETDEVS
 
+/* define if you have devstat_getdevs() */
+#undef HAVE_DEVSTAT_GETDEVS
+
 /* define if you have <netinet/in_pcb.h> */
 #undef HAVE_NETINET_IN_PCB_H
 
@@ -367,7 +370,7 @@
 #ifdef netbsd1
 #define OSTYPE NETBSD1ID
 #endif
-#ifdef freebsd2
+#if defined(__FreeBSD__)
 #define OSTYPE FREEBSDID
 #endif
 #if defined(irix6) || defined(irix5)
@@ -611,13 +614,16 @@
 /* on aix, if you have perfstat */
 #undef HAVE_PERFSTAT
 
+/* define if you have ssize_t */
+#undef HAVE_SSIZE_T
+
 /* Not-to-be-compiled macros for use by configure only */
 #define config_require(x)
 #define config_arch_require(x,y)
 #define config_parse_dot_conf(w,x,y,z)
 #define config_add_mib(x)
   
-#ifdef WIN32
+#if defined (WIN32) || defined (mingw32) || defined (cygwin)
 #define ENV_SEPARATOR ";"
 #define ENV_SEPARATOR_CHAR ';'
 #else
