@@ -167,6 +167,7 @@ netsnmp_create_handler_registration(const char *name,
         the_reg->modes = HANDLER_CAN_DEFAULT;
 
     the_reg->handler = netsnmp_create_handler(name, handler_access_method);
+    the_reg->priority = DEFAULT_MIB_PRIORITY;
     if (name)
         the_reg->handlerName = strdup(name);
     memdup((u_char **) & the_reg->rootoid, (const u_char *) reg_oid,
@@ -230,6 +231,16 @@ netsnmp_register_handler(netsnmp_handler_registration *reginfo)
                                 reginfo, 1);
 }
 
+/** unregister a handler, as defined by the netsnmp_handler_registration pointer. */
+int
+netsnmp_unregister_handler(netsnmp_handler_registration *reginfo)
+{
+    return unregister_mib_context(reginfo->rootoid, reginfo->rootoid_len,
+                                  reginfo->priority,
+                                  reginfo->range_subid, reginfo->range_ubound,
+                                  reginfo->contextName);
+}
+
 /** register a handler, as defined by the netsnmp_handler_registration pointer. */
 int
 netsnmp_register_handler_nocallback(netsnmp_handler_registration *reginfo)
@@ -352,9 +363,17 @@ netsnmp_call_handler(netsnmp_mib_handler *next_handler,
 
     nh = next_handler->access_method;
     if (!nh) {
-        snmp_log(LOG_ERR, "no access method specified in handler %s.",
-                 next_handler->handler_name);
-        return SNMP_ERR_GENERR;
+        if (next_handler->next) {
+            snmp_log(LOG_ERR, "no access method specified in handler %s.",
+                     next_handler->handler_name);
+            return SNMP_ERR_GENERR;
+        }
+        /*
+         * The final handler registration in the chain may well not need
+         * to include a handler routine, if the processing of this object
+         * is handled completely by the agent toolkit helpers.
+         */
+        return SNMP_ERR_NOERROR;
     }
 
     DEBUGMSGTL(("handler:calling", "calling handler %s for mode %s\n",
