@@ -1098,6 +1098,14 @@ netsnmp_table_set_add_indexes(va_alist)
     va_end(debugargs);
 }
 
+int
+netsnmp_table_set_num_rows(netsnmp_table_data_set *table)
+{
+    if (!table)
+        return 0;
+    return netsnmp_table_data_num_rows(table->table);
+}
+
 /*
  * @} 
  */
