@@ -241,6 +241,7 @@ typedef struct ti_cache_info_s {
 static void
 netsnmp_free_ti_cache(void *it) {
     ti_cache_info *beer = it;
+    if (!it) return;
     if (beer->data_context && beer->free_context) {
             (beer->free_context)(beer->data_context, beer->iinfo);
     }
@@ -299,6 +300,7 @@ netsnmp_iterator_remember(netsnmp_request_info *request,
     return ti_info;
 }    
 
+#define TABLE_ITERATOR_NOTAGAIN 255
 /** implements the table_iterator helper */
 int
 netsnmp_table_iterator_helper_handler(netsnmp_mib_handler *handler,
@@ -384,7 +386,7 @@ netsnmp_table_iterator_helper_handler(netsnmp_mib_handler *handler,
                    and take it, comparing to nothing from the request */
                 table_info->colnum = tbl_info->min_column - 1;
             } else if (table_info->colnum > tbl_info->max_column) {
-                request->processed = 1;
+                request->processed = TABLE_ITERATOR_NOTAGAIN;
             }
 
             ti_info =
@@ -533,7 +535,6 @@ netsnmp_table_iterator_helper_handler(netsnmp_mib_handler *handler,
 
                     case MODE_GETNEXT:
                         /* looking for "next" matches */
-                        coloid[reginfo->rootoid_len + 1] = table_info->colnum;
                         if (netsnmp_check_getnext_reply
                             (request, coloid, coloid_len, index_search,
                              &ti_info->results)) {
@@ -601,12 +602,16 @@ netsnmp_table_iterator_helper_handler(netsnmp_mib_handler *handler,
                 for(request = requests ; request; request = request->next) {
                     if (request->processed)
                         continue;
+                    ti_info =
+                        netsnmp_request_get_list_data(request,
+                                                      TI_REQUEST_CACHE);
                     if (!ti_info->results) {
+                        table_info = netsnmp_extract_table_info(request);
                         if (table_info->colnum == tbl_info->max_column) {
                             coloid[reginfo->rootoid_len+1] = table_info->colnum+1;
                             snmp_set_var_objid(request->requestvb,
                                                coloid, reginfo->rootoid_len+2);
-                            requests->processed = 1;
+                            request->processed = TABLE_ITERATOR_NOTAGAIN;
                             break;
                         } else {
                             table_info->colnum++;
@@ -636,8 +641,15 @@ netsnmp_table_iterator_helper_handler(netsnmp_mib_handler *handler,
             switch(reqinfo->mode) {
 
             case MODE_GETNEXT:
-                snmp_set_var_objid(request->requestvb, ti_info->best_match,
-                                   ti_info->best_match_len);
+                if (ti_info->best_match_len)
+                    snmp_set_var_objid(request->requestvb, ti_info->best_match,
+                                       ti_info->best_match_len);
+                else {
+                    coloid[reginfo->rootoid_len+1] = table_info->colnum+1;
+                    snmp_set_var_objid(request->requestvb,
+                                       coloid, reginfo->rootoid_len+2);
+                    request->processed = 1;
+                }
                 snmp_free_varbind(table_info->indexes);
                 table_info->indexes = snmp_clone_varbind(ti_info->results);
                 /* FALL THROUGH */
@@ -692,7 +704,10 @@ netsnmp_table_iterator_helper_handler(netsnmp_mib_handler *handler,
                  * get next skipped this value for this column, we
                  * need to keep searching forward 
                  */
-                request->requestvb->type = ASN_PRIV_RETRY;
+                if (request->processed != TABLE_ITERATOR_NOTAGAIN)
+                    request->requestvb->type = ASN_PRIV_RETRY;
+                else
+                    request->processed = 1;
             }
         }
         reqinfo->mode = oldmode;
