@@ -125,7 +125,7 @@ mibmap          Mibmap[MIBCACHE_SIZE] = {
     {0},
 };
 
-static int      sd = -2;        /* /dev/ip stream descriptor. */
+static int      sd = -2;        /* /dev/arp stream descriptor. */
 
 /*-
  * Static function prototypes (use void as argument type if there are none)
@@ -150,7 +150,7 @@ Name_cmp(void *, void *);
 static void
 init_mibcache_element(mibcache * cp);
 
-#define	STREAM_DEV	"/dev/ip"
+#define	STREAM_DEV	"/dev/arp"
 #define	BUFSIZE		40960   /* Buffer for  messages (should be modulo(pagesize) */
 
 /*-
@@ -813,11 +813,6 @@ getmib(int groupname, int subgroupname, void *statbuf, size_t size,
 	    ret = -1;
 	    goto Return;
 	}
-	if (ioctl(sd, I_PUSH, "arp") == -1) {
-	    snmp_log_perror("I_PUSH arp");
-	    ret = -1;
-	    goto Return;
-	}
 	if (ioctl(sd, I_PUSH, "tcp") == -1) {
 	    snmp_log_perror("I_PUSH tcp");
 	    ret = -1;
@@ -1088,13 +1083,13 @@ getif(mib2_ifEntry_t *ifbuf, size_t size, req_e req_type,
 	    ifp->ifType = 6;
 	    break;
 
-	case 'f':          /* fa (Fore ATM */
+	case 'f':          /* fa (Fore ATM) */
 	    if (!ifp->ifSpeed)
 		ifp->ifSpeed = 155000000;
 	    ifp->ifType = 37;
 	    break;
 
-	case 'q':         /* qe (QuadEther)/qa (Fore ATM)/qfe (QuadFastEther)*/
+	case 'q':         /* qe (QuadEther)/qa (Fore ATM)/qfe (QuadFastEther) */
 	    if (ifrp->ifr_name[1] == 'a') {
 		if (!ifp->ifSpeed)
 		    ifp->ifSpeed = 155000000;
@@ -1109,6 +1104,10 @@ getif(mib2_ifEntry_t *ifbuf, size_t size, req_e req_type,
 		ifp->ifType = 6;
 	    }
 	    break;
+
+	case 'i':          /* ibd (Infiniband) */
+	    ifp->ifType = 199;
+	    break;
 	}
 
 	if (!strchr(ifrp->ifr_name, ':')) {
