@@ -546,14 +546,14 @@ vacm_parse_simple(const char *token, char *confline)
          * com2sec anonymousSecNameNUM    ADDRESS  COMMUNITY 
          */
         sprintf(secname, "anonymousSecName%03d", num);
-        snprintf(line, sizeof(line), "%s %s %s",
+        snprintf(line, sizeof(line), "%s %s '%s'",
                  secname, addressname, community);
         line[ sizeof(line)-1 ] = 0;
         DEBUGMSGTL((token, "passing: %s %s\n", "com2sec", line));
         netsnmp_udp_parse_security("com2sec", line);
 
 #ifdef SNMP_TRANSPORT_UNIX_DOMAIN
-        snprintf(line, sizeof(line), "%s %s %s",
+        snprintf(line, sizeof(line), "%s %s '%s'",
                  secname, addressname, community);
         line[ sizeof(line)-1 ] = 0;
         DEBUGMSGTL((token, "passing: %s %s\n", "com2secunix", line));
@@ -585,7 +585,7 @@ vacm_parse_simple(const char *token, char *confline)
          * com2sec6 anonymousSecNameNUM    ADDRESS  COMMUNITY 
          */
         sprintf(secname, "anonymousSecName%03d", num);
-        snprintf(line, sizeof(line), "%s %s %s",
+        snprintf(line, sizeof(line), "%s %s '%s'",
                  secname, addressname, community);
         line[ sizeof(line)-1 ] = 0;
         DEBUGMSGTL((token, "passing: %s %s\n", "com2sec6", line));
@@ -752,7 +752,7 @@ vacm_in_view(netsnmp_pdu *pdu, oid * name, size_t namelen,
          */
 
         if (pdu->tDomain == netsnmpUDPDomain
-#if SNMP_TRANSPORT_TCP_DOMAIN
+#ifdef SNMP_TRANSPORT_TCP_DOMAIN
             || pdu->tDomain == netsnmp_snmpTCPDomain
 #endif
             ) {
@@ -774,21 +774,11 @@ vacm_in_view(netsnmp_pdu *pdu, oid * name, size_t namelen,
             if (!netsnmp_udp6_getSecName(pdu->transport_data,
                                          pdu->transport_data_length,
                                          (char *) pdu->community,
-                                         pdu->community_len, &sn)
-                && !vacm_is_configured()) {
+                                         pdu->community_len, &sn)) {
                 /*
                  * There are no com2sec entries.  
                  */
-                DEBUGMSGTL(("mibII/vacm_vars",
-                            "vacm_in_view: accepted with no com2sec entries\n"));
-                switch (pdu->command) {
-                case SNMP_MSG_GET:
-                case SNMP_MSG_GETNEXT:
-                case SNMP_MSG_GETBULK:
-                    return 0;
-                default:
-                    return 1;
-                }
+                sn = NULL;
             }
 #endif
 #ifdef SNMP_TRANSPORT_UNIX_DOMAIN
