@@ -69,14 +69,20 @@ static int ps_numdisks;			/* number of disks in system, may change while running
 #endif                          /* bsdi */
 
 #if defined (freebsd4) || defined(freebsd5)
+#include <sys/param.h>
+#if __FreeBSD_version >= 500101
+#include <sys/resource.h>       /* for CPUSTATES in devstat.h */
+#else
 #include <sys/dkstat.h>
+#endif
 #include <devstat.h>
 #endif                          /* freebsd */
 
-#ifdef linux
-#define MAX_DISKS 20
-#include <assert.h>
-#endif /* linux */
+#if defined(freebsd5) && __FreeBSD_version >= 500107
+  #define GETDEVS(x) devstat_getdevs(NULL, (x))
+#else
+  #define GETDEVS(x) getdevs((x))
+#endif
 
 #if defined (darwin)
 #include <CoreFoundation/CoreFoundation.h>
@@ -409,11 +415,17 @@ getstats(void)
     }
     if (stat == NULL) {
         stat = (struct statinfo *) malloc(sizeof(struct statinfo));
-        stat->dinfo = (struct devinfo *) malloc(sizeof(struct devinfo));
+        if (stat != NULL)
+            stat->dinfo = (struct devinfo *) malloc(sizeof(struct devinfo));
+        if (stat == NULL || stat->dinfo == NULL) {
+		SNMP_FREE(stat);
+        	fprintf(stderr, "Memory alloc error - devinfo\n");
+		return 1;
+	}
     }
     memset(stat->dinfo, 0, sizeof(struct devinfo));
 
-    if ((getdevs(stat)) == -1) {
+    if (GETDEVS(stat) == -1) {
         fprintf(stderr, "Can't get devices:%s\n", devstat_errbuf);
         return 1;
     }
@@ -463,16 +475,32 @@ var_diskio(struct variable * vp,
         *var_len = strlen(stat->dinfo->devices[indx].device_name);
         return (u_char *) stat->dinfo->devices[indx].device_name;
     case DISKIO_NREAD:
+#if defined(freebsd5) && __FreeBSD_version >= 500107
+        long_ret = (signed long) stat->dinfo->devices[indx].bytes[DEVSTAT_READ];
+#else
         long_ret = (signed long) stat->dinfo->devices[indx].bytes_read;
+#endif
         return (u_char *) & long_ret;
     case DISKIO_NWRITTEN:
+#if defined(freebsd5) && __FreeBSD_version >= 500107
+        long_ret = (signed long) stat->dinfo->devices[indx].bytes[DEVSTAT_WRITE];
+#else
         long_ret = (signed long) stat->dinfo->devices[indx].bytes_written;
+#endif
         return (u_char *) & long_ret;
     case DISKIO_READS:
+#if defined(freebsd5) && __FreeBSD_version >= 500107
+        long_ret = (signed long) stat->dinfo->devices[indx].operations[DEVSTAT_READ];
+#else
         long_ret = (signed long) stat->dinfo->devices[indx].num_reads;
+#endif
         return (u_char *) & long_ret;
     case DISKIO_WRITES:
+#if defined(freebsd5) && __FreeBSD_version >= 500107
+        long_ret = (signed long) stat->dinfo->devices[indx].operations[DEVSTAT_WRITE];
+#else
         long_ret = (signed long) stat->dinfo->devices[indx].num_writes;
+#endif
         return (u_char *) & long_ret;
 
     default:
@@ -484,94 +512,118 @@ var_diskio(struct variable * vp,
 
 
 #ifdef linux
+
+#define DISK_INCR 2
+
 typedef struct linux_diskio
 {
     int major;
     int  minor;
-    long  blocks;
+    unsigned long  blocks;
     char name[256];
-    long  rio;
-    long  rmerge;
-    long  rsect;
-    long     ruse;
-    long wio;
-    long  wmerge;
-    long  wsect;
-    long  wuse;
-    long  running;
-    long  use;
-    long  aveq;
+    unsigned long  rio;
+    unsigned long  rmerge;
+    unsigned long  rsect;
+    unsigned long  ruse;
+    unsigned long  wio;
+    unsigned long  wmerge;
+    unsigned long  wsect;
+    unsigned long  wuse;
+    unsigned long  running;
+    unsigned long  use;
+    unsigned long  aveq;
 } linux_diskio;
 
 typedef struct linux_diskio_header
 {
     linux_diskio* indices;
     int length;
+    int alloc;
 } linux_diskio_header;
 
-linux_diskio_header head;
-int inited=0;
+static linux_diskio_header head;
 
 
 int getstats(void)
 {
-	FILE* parts;
-	int x = 0;
-  time_t now;
+    FILE* parts;
+    time_t now;
 
-  now = time(NULL);
-  if (cache_time + CACHE_TIMEOUT > now) {
-    return 0;
-  }
+    now = time(NULL);
+    if (cache_time + CACHE_TIMEOUT > now) {
+        return 0;
+    }
 
-        /* remove the indicies and repopulate */
-	if (head.indices)
-		free(head.indices);
-
-
-	head.indices = (struct linux_diskio*)malloc(
-		sizeof(struct linux_diskio[MAX_DISKS]));
-	head.length  = 0;
-
-	memset(head.indices, (sizeof(linux_diskio) * MAX_DISKS), 0);
+    if (!head.indices) {
+	head.alloc = DISK_INCR;
+	head.indices = (linux_diskio *)malloc(head.alloc*sizeof(linux_diskio));
+    }
+    head.length  = 0;
 
+    memset(head.indices, 0, head.alloc*sizeof(linux_diskio));
 
+    /* Is this a 2.6 kernel? */
+    parts = fopen("/proc/diskstats", "r");
+    if (parts) {
+	char buffer[1024];
+	while (fgets(buffer, sizeof(buffer), parts)) {
+	    linux_diskio* pTemp;
+	    if (head.length == head.alloc) {
+		head.alloc += DISK_INCR;
+		head.indices = (linux_diskio *)realloc(head.indices, head.alloc*sizeof(linux_diskio));
+	    }
+	    pTemp = &head.indices[head.length];
+	    sscanf (buffer, "%d %d", &pTemp->major, &pTemp->minor);
+	    if (pTemp->minor == 0)
+		sscanf (buffer, "%d %d %s %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu\n",
+		    &pTemp->major, &pTemp->minor, pTemp->name,
+		    &pTemp->rio, &pTemp->rmerge, &pTemp->rsect, &pTemp->ruse,
+		    &pTemp->wio, &pTemp->wmerge, &pTemp->wsect, &pTemp->wuse,
+		    &pTemp->running, &pTemp->use, &pTemp->aveq);
+	    else
+		sscanf (buffer, "%d %d %s %lu %lu %lu %lu\n",
+		    &pTemp->major, &pTemp->minor, pTemp->name,
+		    &pTemp->rio, &pTemp->rsect,
+		    &pTemp->wio, &pTemp->wsect);
+	    head.length++;
+	}
+    }
+    else {
+	/* See if a 2.4 kernel */
+	char buffer[1024];
 	parts = fopen("/proc/partitions", "r");
-	assert(parts!=NULL);
-
-	while (42)
-	{
-		/*
-		first few fscanfs are garbage we don't care about. skip it.
-		Probably a better way to do this, but I cheaped out on ya :).
-		*/
-		if (x < 2)
-		{
-			char buffer[1024];
-			fgets(buffer, sizeof(buffer), parts);
-		} else {
-			
-			linux_diskio* pTemp = &head.indices[head.length];
-
-			if ((feof(parts) != 0) || head.length >= MAX_DISKS)
-				break;
-
-			fscanf (parts, "%d %d %ld %s %ld %ld %ld %ld %ld %ld %ld %ld %ld %ld %ld\n",
-				&pTemp->major,
-				&pTemp->minor, &pTemp->blocks, pTemp->name, &pTemp->rio,
-				&pTemp->rmerge, &pTemp->rsect, &pTemp->ruse, &pTemp->wio,
-				&pTemp->wmerge, &pTemp->wsect, &pTemp->wuse, &pTemp->running,
-				&pTemp->use, &pTemp->aveq);
-
-			head.length++;
-		}
-		x++;
+	if (!parts) {
+	    snmp_log_perror("/proc/partitions");
+	    return 1;
 	}
 
+	/*
+	 * first few fscanfs are garbage we don't care about. skip it.
+	 */
+	fgets(buffer, sizeof(buffer), parts);
+	fgets(buffer, sizeof(buffer), parts);
 
-	fclose(parts);
-  cache_time = now;
-  return(0);
+	while (! feof(parts)) {
+	    linux_diskio* pTemp;
+
+	    if (head.length == head.alloc) {
+		head.alloc += DISK_INCR;
+		head.indices = (linux_diskio *)realloc(head.indices, head.alloc*sizeof(linux_diskio));
+	    }
+	    pTemp = &head.indices[head.length];
+
+	    fscanf (parts, "%d %d %lu %s %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu\n",
+		    &pTemp->major, &pTemp->minor, &pTemp->blocks, pTemp->name,
+		    &pTemp->rio, &pTemp->rmerge, &pTemp->rsect, &pTemp->ruse,
+		    &pTemp->wio, &pTemp->wmerge, &pTemp->wsect, &pTemp->wuse,
+		    &pTemp->running, &pTemp->use, &pTemp->aveq);
+	    head.length++;
+	}
+    }
+
+    fclose(parts);
+    cache_time = now;
+    return 0;
 }
 
 u_char *
@@ -582,12 +634,12 @@ var_diskio(struct variable * vp,
 	   size_t * var_len,
 	   WriteMethod ** write_method)
 {
-  unsigned int indx;
-  static long long_ret;
+    unsigned int indx;
+    static unsigned long long_ret;
 
-	if (getstats()==1) {
-		return(NULL);
-	}
+    if (getstats() == 1) {
+	return NULL;
+    }
 
  if (header_simple_table(vp, name, length, exact, var_len, write_method, head.length))
     {
@@ -601,26 +653,26 @@ var_diskio(struct variable * vp,
 
   switch (vp->magic) {
     case DISKIO_INDEX:
-      long_ret = (long) indx+1;
+      long_ret = indx+1;
       return (u_char *) &long_ret;
     case DISKIO_DEVICE:
       *var_len = strlen(head.indices[indx].name);
       return (u_char *) head.indices[indx].name;
     case DISKIO_NREAD:
-      long_ret = (signed long) head.indices[indx].rio;
+      long_ret = head.indices[indx].rsect*512;
       return (u_char *) & long_ret;
     case DISKIO_NWRITTEN:
-      long_ret = (signed long) head.indices[indx].wio;
+      long_ret = head.indices[indx].wsect*512;
       return (u_char *) & long_ret;
     case DISKIO_READS:
-      long_ret = (signed long) head.indices[indx].ruse;
+      long_ret = head.indices[indx].rio;
       return (u_char *) & long_ret;
     case DISKIO_WRITES:
-      long_ret = (signed long) head.indices[indx].wuse;
+      long_ret = head.indices[indx].wio;
       return (u_char *) & long_ret;
 
     default:
-      ERROR_MSG("diskio.c: don't know how to handle this request.");
+	snmp_log(LOG_ERR, "diskio.c: don't know how to handle %d request\n", vp->magic);
   }
   return NULL;
 }
