@@ -120,7 +120,8 @@ pass_persist_parse_config(const char *token, char *cptr)
         strncpy((*ppass)->command, cptr, tcptr - cptr);
         (*ppass)->command[tcptr - cptr] = 0;
     }
-    strcpy((*ppass)->name, (*ppass)->command);
+    strncpy((*ppass)->name, (*ppass)->command, sizeof((*ppass)->name));
+    (*ppass)->name[ sizeof((*ppass)->name)-1 ] = 0;
     (*ppass)->next = NULL;
 
     register_mib("pass_persist",
@@ -131,7 +132,7 @@ pass_persist_parse_config(const char *token, char *cptr)
     /*
      * argggg -- pasthrus must be sorted 
      */
-    if (numpersistpassthrus > 0) {
+    if (numpersistpassthrus > 1) {
         etmp = (struct extensible **)
             malloc(((sizeof(struct extensible *)) * numpersistpassthrus));
         if (etmp == NULL)
@@ -249,8 +250,11 @@ var_extensible_pass_persist(struct variable *vp,
                  * persistant scripts return "NONE\n" on invalid items 
                  */
                 if (!strncmp(buf, "NONE", 4)) {
-                    *var_len = 0;
-                    return (NULL);
+                    if (exact) {
+                        *var_len = 0;
+                        return (NULL);
+                    }
+                    continue;
                 }
                 newlen = parse_miboid(buf, newname);
 
@@ -360,7 +364,6 @@ setPassPersist(int action,
     char            buf[SNMP_MAXBUF], buf2[SNMP_MAXBUF];
     long            tmp;
     unsigned long   utmp;
-    int             itmp;
 
     /*
      * Make sure that our basic pipe structure is malloced 
@@ -417,7 +420,6 @@ setPassPersist(int action,
                         (int) ((utmp & 0xff)));
                 break;
             case ASN_OCTET_STR:
-                itmp = sizeof(buf2);
                 memcpy(buf2, var_val, var_val_len);
                 if (var_val_len == 0)
                     sprintf(buf, "string \"\"\n");
