@@ -147,6 +147,8 @@ proxy_parse_config(const char *token, char *line)
             return;
         }
     }
+    if ( context_string )
+        newp->context = strdup(context_string);
 
     DEBUGMSGTL(("proxy_init", "registering at: "));
     DEBUGMSGOID(("proxy_init", newp->name, newp->name_len));
@@ -196,15 +198,19 @@ proxy_free_config(void)
 {
     struct simple_proxy *rm;
 
-    /*
-     * XXX: finish me (needs unregister_mib()) 
-     */
-    return;
-
+    DEBUGMSGTL(("proxy_free_config", "Free config\n"));
     while (proxies) {
         rm = proxies;
         proxies = rm->next;
+
+        DEBUGMSGTL(( "proxy_free_config", "freeing "));
+        DEBUGMSGOID(("proxy_free_config", rm->name, rm->name_len));
+        DEBUGMSG((   "proxy_free_config", " (%s)\n", rm->context));
+        unregister_mib_context(rm->name, rm->name_len,
+                               DEFAULT_MIB_PRIORITY, 0, 0,
+                               rm->context);
         SNMP_FREE(rm->variables);
+        SNMP_FREE(rm->context);
         snmp_close(rm->sess);
         SNMP_FREE(rm);
     }
@@ -218,6 +224,12 @@ init_proxy(void)
                                   "[snmpcmd args] host oid [remoteoid]");
 }
 
+void
+shutdown_proxy(void)
+{
+    proxy_free_config();
+}
+
 int
 proxy_handler(netsnmp_mib_handler *handler,
               netsnmp_handler_registration *reginfo,
