@@ -31,7 +31,7 @@
 
 #include <net-snmp/net-snmp-includes.h>
 #include <net-snmp/agent/net-snmp-agent-includes.h>
-#include "agent/mibgroup/utilities/execute.h"
+#include "utilities/execute.h"
 #include "snmptrapd_handlers.h"
 #include "snmptrapd_log.h"
 
@@ -481,6 +481,7 @@ int   syslog_handler(  netsnmp_pdu           *pdu,
             trunc = !realloc_format_trap(&rbuf, &r_len, &o_len, 1,
                                      handler->format, pdu, transport);
         } else {
+            free(rbuf);
             return NETSNMPTRAPD_HANDLER_OK;    /* A 0-length format string means don't log */
         }
 
@@ -567,6 +568,7 @@ int   print_handler(   netsnmp_pdu           *pdu,
             trunc = !realloc_format_trap(&rbuf, &r_len, &o_len, 1,
                                      handler->format, pdu, transport);
         } else {
+            free(rbuf);
             return NETSNMPTRAPD_HANDLER_OK;    /* A 0-length format string means don't log */
         }
 
@@ -604,6 +606,7 @@ int   print_handler(   netsnmp_pdu           *pdu,
         }
     }
     snmp_log(LOG_INFO, "%s%s", rbuf, (trunc?" [TRUNCATED]\n":""));
+    free(rbuf);
     return NETSNMPTRAPD_HANDLER_OK;
 }
 
@@ -808,8 +811,9 @@ int   command_handler( netsnmp_pdu           *pdu,
          */
         run_exec_command(handler->token, rbuf, NULL, 0);   /* Not interested in output */
         snmp_set_quick_print(oldquick);
-	if (pdu->command == SNMP_MSG_TRAP)
-	    snmp_free_pdu(v2_pdu);
+        if (pdu->command == SNMP_MSG_TRAP)
+            snmp_free_pdu(v2_pdu);
+        free(rbuf);
     }
     return NETSNMPTRAPD_HANDLER_OK;
 }
@@ -864,7 +868,10 @@ int   forward_handler( netsnmp_pdu           *pdu,
         pdu2->transport_data        = NULL;
         pdu2->transport_data_length = 0;
     }
-    snmp_send( ss, pdu2 );
+    if (!snmp_send( ss, pdu2 )) {
+	snmp_sess_perror("Forward failed", ss);
+	snmp_free_pdu(pdu2);
+    }
     snmp_close( ss );
     return NETSNMPTRAPD_HANDLER_OK;
 }
@@ -946,6 +953,7 @@ snmp_input(int op, netsnmp_session *session,
 	            /*
 		     * Still can't find it!  Give up.
 		     */
+		    snmp_log(LOG_ERR, "Cannot find TrapOID in TRAP2 PDU\n");
 		    return 1;		/* ??? */
 		}
 	    }
@@ -1052,10 +1060,10 @@ t        *     d) any other global handlers
         break;
 
     case NETSNMP_CALLBACK_OP_TIMED_OUT:
-        fprintf(stderr, "Timeout: This shouldn't happen!\n");
+        snmp_log(LOG_ERR, "Timeout: This shouldn't happen!\n");
         break;
     default:
-        fprintf(stderr, "Unknown operation (%d): This shouldn't happen!\n", op);
+        snmp_log(LOG_ERR, "Unknown operation (%d): This shouldn't happen!\n", op);
         break;
     }
     return 0;
