@@ -348,8 +348,8 @@ main(int argc, char *argv[])
                 i++;
             }
 	} else {
-            for (i=0 ; i < (name_length+7)/8; i++)
-                viewMask[i] = 0xff;
+            for (i=0 ; i < ((int)name_length+7)/8; i++)
+                viewMask[i] = (u_char)0xff;
         }
         view_oid(vacmViewTreeFamilyMask, &name_length, argv[arg],
                  argv[arg + 1]);
