@@ -7,7 +7,7 @@
 #     modify it under the same terms as Perl itself.
 
 package SNMP;
-$VERSION = '5.1.1';   # current release version number
+$VERSION = '5.1.2';   # current release version number
 
 require Exporter;
 require DynaLoader;
@@ -2065,7 +2065,7 @@ net-snmp-users@net-snmp-users@lists.sourceforge.net
 please give sufficient information to analyze the problem (OS type,
 versions for OS/Perl/UCD/compiler, complete error output, etc.)
 
-=head1 Acknowledments
+=head1 Acknowledgements
 
 Many thanks to all those who supplied patches, suggestions and
 feedback.
@@ -2085,7 +2085,13 @@ feedback.
  Wayne Marquette
  Scott Schumate
  Michael Slifcak
+ Srivathsan Srinivasagopalan
+ Bill Fenner
+ Jef Peeraer
+ Daniel Hagerty
+ Karl "Rat" Schilke and Electric Lightwave, Inc.
  Perl5 Porters
+ Alex Burger
 
 Apologies to any/all who's patch/feature/request was not mentioned or
 included - most likely it was lost when paying work intruded on my
@@ -2107,4 +2113,5 @@ bugs, comments, questions to net-snmp-users@lists.sourceforge.net
      Rights Reserved.  This program is free software; you can
      redistribute it and/or modify it under the same terms as Perl
      itself.
+
 =cut
