@@ -1,7 +1,7 @@
 /*
  * netsnmp_data_list.c
  *
- * $Id: data_list.c,v 5.5 2003/09/17 23:32:07 rstory Exp $
+ * $Id: data_list.c,v 5.5.2.1 2004/02/04 11:25:20 slif Exp $
  */
 #include <net-snmp/net-snmp-config.h>
 #include <net-snmp/net-snmp-includes.h>
@@ -293,7 +293,7 @@ netsnmp_save_all_data(netsnmp_data_list *head,
             /* save begining of line */
             snprintf(buf, sizeof(buf), "%s ", token);
             cp = buf + strlen(buf);
-            cp = read_config_save_octet_string(cp, head->name,
+            cp = read_config_save_octet_string(cp, (u_char*)head->name,
                                                strlen(head->name));
             *cp++ = ' ';
 
