@@ -488,9 +488,14 @@ snmp_config_when(char *line, int when)
     cptr = strtok(buf, SNMP_CONFIG_DELIMETERS);
     if (cptr && cptr[0] == '[') {
         if (cptr[strlen(cptr) - 1] != ']') {
-            config_perror("no matching ']'");
+            snprintf(tmpbuf, sizeof(tmpbuf),
+                    "no matching ']' for type %s.",
+                    cptr + 1);
+            tmpbuf[ sizeof(tmpbuf)-1 ] = 0;
+            config_perror(tmpbuf);
             return SNMPERR_GENERR;
         }
+        cptr[strlen(cptr) - 1] = '\0';
         lptr = read_config_get_handlers(cptr + 1);
         if (lptr == NULL) {
             snprintf(tmpbuf,  sizeof(tmpbuf),
@@ -686,6 +691,14 @@ read_config(const char *filename,
         if ((cptr = skip_white(cptr))) {
             cptr = copy_nword(cptr, token, sizeof(token));
             if (token[0] == '[') {
+                if (token[strlen(token) - 1] != ']') {
+                    snprintf(tmpbuf, sizeof(tmpbuf),
+                            "no matching ']' for type %s.",
+                            &token[1]);
+                    tmpbuf[ sizeof(tmpbuf)-1 ] = 0;
+                    config_perror(tmpbuf);
+                    continue;
+                }
                 token[strlen(token) - 1] = '\0';
                 lptr = read_config_get_handlers(&token[1]);
                 if (lptr == NULL) {
@@ -1229,7 +1242,7 @@ snmp_save_persistent(const char *type)
      * save a warning header to the top of the new file 
      */
     snprintf(fileold, sizeof(fileold),
-            "#\n# net-snmp (or ucd-snmp) persistent data file.\n#\n# DO NOT STORE CONFIGURATION ENTRIES HERE.\n# Please save normal configuration tokens for %s in SNMPCONFPATH/%s.conf.\n# Only \"createUser\" tokens should be placed here by %s administrators.\n#\n",
+            "#\n# net-snmp (or ucd-snmp) persistent data file.\n#\n############################################################################\n# STOP STOP STOP STOP STOP STOP STOP STOP STOP \n#\n#          **** DO NOT EDIT THIS FILE ****\n#\n# STOP STOP STOP STOP STOP STOP STOP STOP STOP \n############################################################################\n#\n# DO NOT STORE CONFIGURATION ENTRIES HERE.\n# Please save normal configuration tokens for %s in SNMPCONFPATH/%s.conf.\n# Only \"createUser\" tokens should be placed here by %s administrators.\n# (Did I mention: do not edit this file?)\n#\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n",
             type, type, type);
     fileold[ sizeof(fileold)-1 ] = 0;
     read_config_store(type, fileold);
@@ -1356,6 +1369,8 @@ char           *
 copy_nword(char *from, char *to, int len)
 {
     char            quote;
+    if ( !from || !to )
+        return NULL;
     if ((*from == '\"') || (*from == '\'')) {
         quote = *(from++);
         while ((*from != quote) && (*from != 0)) {
