@@ -40,6 +40,11 @@
 #include <netdb.h>
 #endif
 
+#if HAVE_WINSOCK_H
+#include <winsock2.h>
+#include <ws2tcpip.h>
+#endif
+
 #if HAVE_DMALLOC_H
 #include <dmalloc.h>
 #endif
@@ -488,7 +493,9 @@ com2SecEntry   *com2SecList = NULL, *com2SecListLast = NULL;
 void
 netsnmp_udp_parse_security(const char *token, char *param)
 {
-    char           *secName = NULL, *community = NULL, *source = NULL;
+    char           secName[VACMSTRINGLEN];
+    char           source[VACMSTRINGLEN];
+    char           community[VACMSTRINGLEN];
     char           *cp = NULL;
     const char     *strmask = NULL;
     com2SecEntry   *e = NULL;
@@ -498,16 +505,16 @@ netsnmp_udp_parse_security(const char *token, char *param)
      * Get security, source address/netmask and community strings.  
      */
 
-    secName = strtok(param, "\t\n ");
-    if (secName == NULL) {
+    cp = copy_nword(param, secName, sizeof(secName));
+    if (secName[0] == '\0') {
         config_perror("missing NAME parameter");
         return;
     } else if (strlen(secName) > (VACMSTRINGLEN - 1)) {
         config_perror("security name too long");
         return;
     }
-    source = strtok(NULL, "\t\n ");
-    if (source == NULL) {
+    cp = copy_nword(cp, source, sizeof(source));
+    if (source[0] == '\0') {
         config_perror("missing SOURCE parameter");
         return;
     } else if (strncmp(source, EXAMPLE_NETWORK, strlen(EXAMPLE_NETWORK)) ==
@@ -515,8 +522,8 @@ netsnmp_udp_parse_security(const char *token, char *param)
         config_perror("example config NETWORK not properly configured");
         return;
     }
-    community = strtok(NULL, "\t\n ");
-    if (community == NULL) {
+    cp = copy_nword(cp, community, sizeof(community));
+    if (community[0] == '\0') {
         config_perror("missing COMMUNITY parameter\n");
         return;
     } else
