@@ -1,5 +1,22 @@
 #include <net-snmp/net-snmp-config.h>
 
+#ifdef SNMP_TRANSPORT_UDPIPV6_DOMAIN
+
+/*
+ * hack-o-matic for Cygwin to use winsock2
+*/
+#if defined(cygwin)
+#undef HAVE_UNISTD_H
+#undef HAVE_NETINET_IN_H
+#undef HAVE_ARPA_INET_H
+#undef HAVE_NET_IF_H
+#undef HAVE_NETDB_H
+#undef HAVE_SYS_PARAM_H
+#undef HAVE_SYS_SELECT_H
+#undef HAVE_SYS_SOCKET_H
+#undef HAVE_IN_ADDR_T
+#endif
+
 #include <stdio.h>
 #include <sys/types.h>
 #include <ctype.h>
@@ -21,13 +38,12 @@
 #endif
 
 #define HAVE_IF_NAMETOINDEX
-#if HAVE_WINSOCK_H
+#if defined(HAVE_WINSOCK_H) || defined(cygwin)
     /*
      *  Windows IPv6 support is part of WinSock2 only
      */
 #include <winsock2.h>
 #include <ws2tcpip.h>
-typedef unsigned char uint8_t;
 #undef  HAVE_IF_NAMETOINDEX
 
 extern int         inet_pton(int, const char*, void*);
@@ -294,6 +310,7 @@ netsnmp_udp6_transport(struct sockaddr_in6 *addr, int local)
         if (t->local == NULL) {
             netsnmp_udp6_close(t);
             netsnmp_transport_free(t);
+            return NULL;
         }
         memcpy(t->local, addr->sin6_addr.s6_addr, 16);
         t->local[16] = (addr->sin6_port & 0xff00) >> 8;
@@ -309,6 +326,7 @@ netsnmp_udp6_transport(struct sockaddr_in6 *addr, int local)
 
         t->data = malloc(sizeof(struct sockaddr_in6));
         if (t->data == NULL) {
+            netsnmp_udp6_close(t);
             netsnmp_transport_free(t);
             return NULL;
         }
@@ -541,10 +559,16 @@ netsnmp_sockaddr_in6(struct sockaddr_in6 *addr,
             free(peername);
             return 0;
         }
+        if (addrs != NULL) {
         DEBUGMSGTL(("netsnmp_sockaddr_in6", "hostname (resolved okay)\n"));
         memcpy(&addr->sin6_addr,
                &((struct sockaddr_in6 *) addrs->ai_addr)->sin6_addr,
                sizeof(struct in6_addr));
+		freeaddrinfo(addrs);
+        }
+		else {
+        DEBUGMSGTL(("netsnmp_sockaddr_in6", "Failed to resolve IPv6 hostname\n"));
+		}
 #elif HAVE_GETIPNODEBYNAME
         hp = getipnodebyname(peername, AF_INET6, 0, &err);
         if (hp == NULL) {
@@ -642,20 +666,20 @@ inet_make_mask_addr(int pf, void *dst, int masklength)
 
 
         for (i = 0; i < 16; i++) {
-            (*(uint8_t *) (&((struct in6_addr *) dst)->s6_addr[i])) = 0x00;
+            (*(u_char *) (&((struct in6_addr *) dst)->s6_addr[i])) = 0x00;
         }
 
         j = (int) masklength / 8;
         jj = masklength % 8;
 
         for (i = 0; i < j; i++) {
-            (*(uint8_t *) (&((struct in6_addr *) dst)->s6_addr[i])) = 0xff;
+            (*(u_char *) (&((struct in6_addr *) dst)->s6_addr[i])) = 0xff;
         }
         while (jj--) {
             mask |= maskbit;
             maskbit >>= 1;
         }
-        (*(uint8_t *) (&((struct in6_addr *) dst)->s6_addr[j])) = mask;
+        (*(u_char *) (&((struct in6_addr *) dst)->s6_addr[j])) = mask;
         break;
     default:
         return -1;              /* unsupported protocol family */
@@ -690,8 +714,8 @@ inet_addr_complement(int pf, void *src, void *dst)
         break;
     case PF_INET6:
         for (i = 0; i < 16; i++) {
-            (*(uint8_t *) (&((struct in6_addr *) dst)->s6_addr[i])) =
-                (~(*(uint8_t *) (&((struct in6_addr *) src)->s6_addr[i])))
+            (*(u_char *) (&((struct in6_addr *) dst)->s6_addr[i])) =
+                (~(*(u_char *) (&((struct in6_addr *) src)->s6_addr[i])))
                 & 0xff;
         }
         break;
@@ -728,9 +752,9 @@ inet_addr_and(int pf, void *src1, void *src2, void *dst)
 
     case PF_INET6:
         for (i = 0; i < 16; i++) {
-            (*(uint8_t *) (&((struct in6_addr *) dst)->s6_addr[i])) =
-                (*(uint8_t *) (&((struct in6_addr *) src1)->s6_addr[i])) &
-                (*(uint8_t *) (&((struct in6_addr *) src2)->s6_addr[i]));
+            (*(u_char *) (&((struct in6_addr *) dst)->s6_addr[i])) =
+                (*(u_char *) (&((struct in6_addr *) src1)->s6_addr[i])) &
+                (*(u_char *) (&((struct in6_addr *) src2)->s6_addr[i]));
         }
         break;
     default:
@@ -927,7 +951,9 @@ memmove_com2Sec6Entry(com2Sec6Entry * c,
 void
 netsnmp_udp6_parse_security(const char *token, char *param)
 {
-    char           *secName = NULL, *community = NULL, *source = NULL;
+    char           secName[VACMSTRINGLEN];
+    char           source[VACMSTRINGLEN];
+    char           community[VACMSTRINGLEN];
     char           *cp = NULL, *strnetwork = NULL, *strmask = NULL;
     com2Sec6Entry  *e = NULL;
     struct sockaddr_in6 net, mask;
@@ -944,16 +970,16 @@ netsnmp_udp6_parse_security(const char *token, char *param)
     /*
      * Get security, source address/netmask and community strings.  
      */
-    secName = strtok(param, "\t\n ");
-    if (secName == NULL) {
+    cp = copy_nword(param, secName, sizeof(secName));
+    if (secName[0] == '\0') {
         config_perror("missing NAME parameter");
         return;
     } else if (strlen(secName) > (VACMSTRINGLEN - 1)) {
         config_perror("security name too long");
         return;
     }
-    source = strtok(NULL, "\t\n ");
-    if (source == NULL) {
+    cp = copy_nword(cp, source, sizeof(source));
+    if (source[0] == '\0') {
         config_perror("missing SOURCE parameter");
         return;
     } else if (strncmp(source, EXAMPLE_NETWORK, strlen(EXAMPLE_NETWORK)) ==
@@ -961,8 +987,8 @@ netsnmp_udp6_parse_security(const char *token, char *param)
         config_perror("example config NETWORK not properly configured");
         return;
     }
-    community = strtok(NULL, "\t\n ");
-    if (community == NULL) {
+    cp = copy_nword(cp, community, sizeof(community));
+    if (community[0] == '\0') {
         config_perror("missing COMMUNITY parameter\n");
         return;
     } else
@@ -1084,7 +1110,10 @@ netsnmp_udp6_parse_security(const char *token, char *param)
                 com2Sec6ListLast = com2Sec6List = e;
             }
 
+#if HAVE_GETADDRINFO
+
         } else {
+
             /*
              * Nope, Must be a hostname.  
              */
@@ -1132,7 +1161,11 @@ netsnmp_udp6_parse_security(const char *token, char *param)
             }
             if (res != NULL)
                 freeaddrinfo(res);
+
+#endif /* HAVE_GETADDRINFO */
+
         }
+
         /*
          * free(strnetwork); 
          */
@@ -1222,7 +1255,7 @@ netsnmp_udp6_getSecName(void *opaque, int olength,
                     "compare <\"%s\", 0x%032/0x%032x>", c->community,
                     c->network, c->mask));
 
-        if ((community_len == strlen(c->community)) &&
+        if ((community_len == (int)strlen(c->community)) &&
             (memcmp(community, c->community, community_len) == 0) &&
             (masked_address_are_equal(from->sin6_family,
                                       (struct sockaddr_storage *) from,
@@ -1296,3 +1329,15 @@ netsnmp_udp6_ctor(void)
 
     netsnmp_tdomain_register(&udp6Domain);
 }
+
+#else
+
+#ifdef NETSNMP_DLL
+/* need this hook for win32 MSVC++ DLL build */
+void
+netsnmp_udp6_agent_config_tokens_register(void)
+{ }
+#endif
+
+#endif /* SNMP_TRANSPORT_UDPIPV6_DOMAIN */
+
