@@ -540,7 +540,7 @@ winsock_startup(void)
 	/* winsock 1: use MAKEWORD(1,1) */
 	/* winsock 2: use MAKEWORD(2,2) */
 
-    VersionRequested = MAKEWORD(1,1);
+    VersionRequested = MAKEWORD(2,2);
     i = WSAStartup(VersionRequested, &stWSAData);
     if (i != 0) {
         if (i == WSAVERNOTSUPPORTED)
@@ -966,17 +966,24 @@ mkdirhier(const char *pathname, mode_t mode, int skiplast)
     char           *entry;
     char            buf[SNMP_MAXPATH];
 
+#if defined (WIN32) || defined (cygwin)
+    /* convert backslash to forward slash */
+    for (entry = ourcopy; *entry; entry++)
+        if (*entry == '\\')
+            *entry = '/';
+#endif
+
     entry = strtok(ourcopy, "/");
 
     buf[0] = '\0';
 
-#ifdef WIN32
+#if defined (WIN32) || defined (cygwin)
     /*
      * Check if first entry contains a drive-letter
-     *   e.g  "c:\path"
+     *   e.g  "c:/path"
      */
     if ((entry) && (':' == entry[1]) &&
-        (('\0' == entry[2]) || ('/' == entry[2]) || ('\\' == entry[1]))) {
+        (('\0' == entry[2]) || ('/' == entry[2]))) {
         strcat(buf, entry);
         entry = strtok(NULL, "/");
     }
